OpenTelemetry Distro
====================

|pypi|

.. |pypi| image:: https://badge.fury.io/py/opentelemetry-distro.svg
   :target: https://pypi.org/project/opentelemetry-distro/

Installation
------------

::

    pip install opentelemetry-distro


This package provides entrypoints to configure OpenTelemetry.

References
----------

* `OpenTelemetry Project <https://opentelemetry.io/>`_
* `Example using opentelemetry-distro <https://opentelemetry.io/docs/instrumentation/python/distro/>`_
